import math
import numpy as np
import matplotlib.pyplot as plt
import matplotlib
from matplotlib.ticker import AutoMinorLocator

matplotlib.rcParams['ytick.minor.size'] = 5
matplotlib.rcParams['ytick.minor.width'] = 1

matplotlib.rcParams['xtick.minor.size'] = 5
matplotlib.rcParams['xtick.minor.width'] = 1.5


fig, ax = plt.subplots()
ax.set_xscale("log", basex=2)
ax.set_yscale("log", basey=2)


p = [2048, 4096, 8192, 16384, 32768]
changa_lambb_HSS = [1.11165, 1.21807, 2.40409, 4.78085, 8.62414]
#for i in range(0, len(p)):
#	changa_lambb_HSS[i] = 1000 * changa_lambb_HSS[i]/p[i]
pcolor_lambb = '#0e326d'
plt.plot(p, changa_lambb_HSS, ':', color=pcolor_lambb,  lw=2.5,  marker='o', mew = 2.5, markersize = 10, markerfacecolor=pcolor_lambb, markeredgecolor=pcolor_lambb, dash_capstyle='round', label='HSS Lambb')


p = [2048, 4096, 8192, 16384, 32768]
changa_lambb_old = [1.20458, 1.55362, 3.11297, 6.24931, 11.4735]
#for i in range(0, len(p)):
#	changa_lambb_old[i] = 1000 * changa_lambb_old[i]/p[i]

plt.plot(p, changa_lambb_old, '-', color=pcolor_lambb,  lw=2.5,  marker='o', mew = 2.5, markersize = 10, markerfacecolor='none', markeredgecolor=pcolor_lambb, dash_capstyle='round', label='Histogram Sort Lambb')




pcolor_dwarf = '#028413'
p = [512, 1024, 2048, 4096]
changa_dwarf_HSS = [0.274655, 0.321575, 0.518289, 0.90698]
#for i in range(0, len(p)):
#	changa_dwarf_HSS[i] = 1000 * changa_dwarf_HSS[i]/p[i]
plt.plot(p, changa_dwarf_HSS, ':', color=pcolor_dwarf,  lw=2.5,  marker='s', mew = 2.5, markersize = 10, markerfacecolor=pcolor_dwarf, markeredgecolor=pcolor_dwarf, dash_capstyle='round', label='HSS Dwarf')



p = [512, 1024, 2048, 4096]
changa_dwarf_old = [0.278324, 0.354976, 0.5974, 1.10567]

#for i in range(0, len(p)):
#	changa_dwarf_old[i] = 1000 * changa_dwarf_old[i]/p[i]
plt.plot(p, changa_dwarf_old, '-', color=pcolor_dwarf,  lw=2.5,  marker='s', mew = 2.5, markersize = 10, markerfacecolor='none', markeredgecolor=pcolor_dwarf, dash_capstyle='round', label='Histogram Sort Dwarf')


label_fontsize=15

leg = plt.legend(bbox_to_anchor=(0.05, 0.9), borderaxespad=0, loc=2, numpoints=3, handlelength=5)
leg.get_frame().set_linewidth(0.0)



axcolor='grey'
ax.xaxis.set_tick_params(width=2, length=10)
ax.yaxis.set_tick_params(width=2, length=15)
ax.xaxis.set_tick_params(which='both', colors=axcolor)
ax.yaxis.set_tick_params(which='both', colors=axcolor)


ax.spines['bottom'].set_color(axcolor)
ax.spines['top'].set_color(axcolor) 
ax.spines['right'].set_color(axcolor)
ax.spines['left'].set_color(axcolor)

def string(x):
    if x >= 1024:
    		return str(x/1024) + 'K'
    else:
        return str(x)


hfont = {'fontname':'Lato'}
plt.xlabel("#processors", fontsize=label_fontsize)
plt.ylabel("Execution Time(sec)", fontsize=label_fontsize)


ticklabelcolor = 'grey'

logps = np.arange(8,17,1)
ax.xaxis.set_ticks(np.array([2**x for x in logps]))
xticks = np.array([2**x for x in logps])
xticks = np.array([string(x) for x in xticks])
ax.set_xticklabels(xticks, color=ticklabelcolor)


yticks = [2**x for x in np.arange(0, 5, 1)]
yticks = [0.5] + yticks
ax.yaxis.set_ticks(np.array(yticks))
aaaa = ["",".0"]
yticks = np.array([string(x) + aaaa[min(1, int(x))] for x in yticks])
ax.set_yticklabels(yticks, color=ticklabelcolor)



# yticks = np.arange(0,24,4)
# ax.yaxis.set_ticks(yticks)
# ax.yaxis.set_minor_locator(AutoMinorLocator(8))
# ax.set_yticklabels(yticks, color=ticklabelcolor)



#plt.xlim(xmin=500)
#plt.ylim(ymin=0, ymax=18)
plt.tick_params(labelsize=label_fontsize)

plt.grid(linestyle=':', linewidth=1, color='grey')

#plt.show()
plt.savefig("changa-hss.pdf")
#plt.savefig('/Users/vipulharsh/Desktop/psortingV/doc/2017ipdps-parsort/PAPER/fig2.eps')
