import math
import numpy as np
import matplotlib.pyplot as plt
import matplotlib

matplotlib.rcParams['ytick.minor.size'] = 3
matplotlib.rcParams['ytick.minor.width'] = 1

matplotlib.rcParams['xtick.minor.size'] = 6
matplotlib.rcParams['xtick.minor.width'] = 1.5


fig, ax = plt.subplots()
ax.set_xscale("log", basex=2)
ax.set_yscale("log", basey=2)

p = [2048, 4096, 8192, 16384, 32768]
localsort = [1.231, 1.263, 1.266, 1.444, 1.927]
chisttime = [1.556, 1.902, 2.575, 4.145, 8.271]
cdataexchange = [4.269, 5.047, 5.799, 9.212, 16.683]
histtime = [a_i - b_i for a_i, b_i in zip(chisttime, localsort)]
dataexchange = [a_i - b_i for a_i, b_i in zip(cdataexchange, chisttime)]


pcolor = '#af0505'
pcolor = '#028413'
plt.plot(p, histtime, '-', color=pcolor,  lw=2.5,  marker='o', mew = 2.5, markersize = 10, markerfacecolor='none', markeredgecolor=pcolor, dash_capstyle='round', label='Histogramming')


pcolor = '#0e326d'
plt.plot(p, dataexchange, '-', color=pcolor,  lw=2.5,  marker='x', mew = 2.5, markersize = 10, markerfacecolor='none', markeredgecolor=pcolor, dash_capstyle='round', label='Data Exchange')




label_fontsize=15

leg = plt.legend(bbox_to_anchor=(0.10, 0.9), borderaxespad=0, loc=2, numpoints=3, handlelength=5, fontsize=label_fontsize)
leg.get_frame().set_linewidth(0.0)



axcolor='grey'
#ax.xaxis.set_tick_params(width=2, length=10)
#ax.yaxis.set_tick_params(width=2, length=10)
#ax.xaxis.set_tick_params(which='both', colors=axcolor)
#ax.yaxis.set_tick_params(which='both', colors=axcolor)


ax.spines['bottom'].set_color(axcolor)
ax.spines['top'].set_color(axcolor) 
ax.spines['right'].set_color(axcolor)
ax.spines['left'].set_color(axcolor)


def string(x):
    if x >= 1024:
    		return str(x/1024) + 'K'
    else:
        return str(x)


hfont = {'fontname':'Lato'}
plt.xlabel("#PEs", fontsize=label_fontsize)
plt.ylabel("Execution Time(sec)", fontsize=label_fontsize)


ticklabelcolor = 'black' #'grey'
logps = np.arange(10,17,1)
xticks = np.array([2**x for x in logps])
ax.xaxis.set_ticks(xticks)
xticks = np.array([string(x) for x in xticks])
ax.set_xticklabels(xticks, color=ticklabelcolor)

logps = np.arange(-1,6,1)
print logps
ax.yaxis.set_ticks(np.array([2.0**x for x in logps]))
yticks = np.array([2.0**x for x in logps])
yticks = np.array([string(x) for x in yticks])
ax.set_yticklabels(yticks, color=ticklabelcolor, fontsize=label_fontsize)

plt.tick_params(labelsize=label_fontsize)
#plt.xlim(xmin=500)
plt.ylim(ymin=-2, ymax=10)

plt.grid(linestyle=':', linewidth=1, color='grey')
plt.savefig('histtime.pdf')
#plt.show()
