import math
import numpy as np
import matplotlib.pyplot as plt
import matplotlib
from matplotlib.ticker import LogLocator



#set width, size of minor axis ticks
matplotlib.rcParams['ytick.minor.size'] = 3
matplotlib.rcParams['ytick.minor.width'] = 1

matplotlib.rcParams['xtick.minor.size'] = 6
matplotlib.rcParams['xtick.minor.width'] = 1.5


fig, ax = plt.subplots()
ax.set_xscale("log", basex=4)
ax.set_yscale("log", basey=4)

logp = np.arange(4,19,1)
logp_base2 = np.array([x*math.log(2) for x in logp])
p = np.array([2**i for i in logp])
p2 = np.array([i*i for i in p])
p2_20 = np.array([i*20 for i in p2])
plogp_20 = np.array([x*y*20*math.log(2) for x, y in zip(logp, p)])
plog_log_p_20 = np.array([math.log(x*20*math.log(2)) * 2.7 *  y for x, y in zip(logp, p)])
plogp_20_20 = np.array([x*20*1.05 for x in plogp_20])
plogp_plus_20 = np.array([p[i] * 2 * (logp_base2[i] + 20) for i in range(0, len(logp_base2))])
proot_logp_20 = np.array([(y* 2 * math.sqrt(20 * x * math.log(2)))  for x, y in zip(logp, p)])

print math.log(2)
#plt.plot(p, p2, '-b',      mew = 2, markersize = 8, markerfacecolor="None", markeredgecolor="blue", label="quad")
#rounded fonts

for i in range(len(p)):
	print p[i], p2_20[i], plogp_20_20[i], plogp_20[i], proot_logp_20[i], plog_log_p_20[i]



#plt.plot(p, p2_20, '-', color='#0e326d',  lw=2.1, dash_capstyle='round', label="regular sampling",  marker='^')

#plt.plot(p, p2_20, '-', color='#999999',  lw=2.1, dash_capstyle='round', label="regular sampling",  marker='^')
plt.plot(p, plogp_plus_20, '-', color='#999999',  lw=2.1, dash_capstyle='round', label="AMS sort scanning algorithm",  marker='^')
plt.plot(p, plogp_20_20, '-', color='#af0505', lw=2.1, dash_capstyle='round', label="sample sort: random sampling")
plt.plot(p, plogp_20, '--', color='#028413', lw=2.5, dash_capstyle='round', label="HSS: 1 round")
#plt.plot(p, proot_logp_20, ':', color='#e06c0d', lw=2.5, dash_capstyle='round', label="HSS - 2 rounds", marker='.')
plt.plot(p, plog_log_p_20, '-', color='#111111', lw=1.8, dash_capstyle='round', label="HSS: optimal rounds", marker='o')

label_fontsize=15
leg = plt.legend(bbox_to_anchor=(0.03, 0.98), borderaxespad=0, loc=2, numpoints=3, handlelength=5,prop={'size':12}, fontsize=label_fontsize)
leg.get_frame().set_linewidth(0.0)
plt.xlabel("#processors", fontsize=label_fontsize)
plt.ylabel("Sample size (#keys)", fontsize=label_fontsize)


#set tick colors
axcolor='grey'
ax.xaxis.set_tick_params(width=2, length=10)
ax.yaxis.set_tick_params(width=2, length=10)
ax.xaxis.set_tick_params(which='both', colors=axcolor) #both major and minor ticks
ax.yaxis.set_tick_params(which='both', colors=axcolor)


#4 different spines of the axis
axcolor='grey'
axcolor2='grey'
ax.spines['bottom'].set_color(axcolor)
ax.spines['top'].set_color(axcolor2) 
ax.spines['right'].set_color(axcolor2)
ax.spines['left'].set_color(axcolor)
#ax.spines['top'].set_visible(False)
#ax.spines['right'].set_visible(False)
ax.get_xaxis().tick_bottom()
ax.get_yaxis().tick_left()


def string(x):
    if x >= (1024 * 1024 * 1024):
        return str(x/(1024*1024*1024)) + 'B'    
    elif x >= (1024 * 1024):
        return str(x/(1024*1024)) + 'M'
    elif x >= 1024:
        return str(x/1024) + 'K'
    else:
        return str(x)

ticklabelcolor = 'black'
logp = np.arange(3,19,1)
p = np.array([2**i for i in logp])
ax.xaxis.set_ticks(p[1::2])
xticks =np.array([2**x for x in logp[1::2]])
xticks = np.array([string(x) for x in xticks])
ax.set_xticklabels(xticks, color=ticklabelcolor)
logps = np.arange(0,32,4)
ax.yaxis.set_ticks(np.array([2**x for x in logps]))

#set minor ticks for log scale on base*i*[4.0,8.0,12.0]
ax.yaxis.set_minor_locator(LogLocator(base=4, subs=[4.0,8.0,12.0]))

yticks = np.array([2**x for x in logps])
yticks = np.array([string(x) for x in yticks])
ax.set_yticklabels(yticks, color=ticklabelcolor)
ax.yaxis.grid()
plt.tick_params(labelsize=label_fontsize)


plt.tight_layout()
#plt.grid(linestyle=':', linewidth=1, color='grey')
plt.savefig('samplesize.pdf')
#plt.show()
