import math
import numpy as np
import matplotlib.pyplot as plt
import matplotlib

matplotlib.rcParams['ytick.minor.size'] = 3
matplotlib.rcParams['ytick.minor.width'] = 1

matplotlib.rcParams['xtick.minor.size'] = 6
matplotlib.rcParams['xtick.minor.width'] = 1.5


fig, ax = plt.subplots()
ax.set_xscale("log", basex=2)

p = [2048, 4096, 8192, 16384, 32768]
usort = [4.0205, 4.6332, 4.8508, 4.9915, 5.0123]
pcolor = '#af0505'
pcolor = '#028413'
plt.plot(p, usort, '-', color=pcolor,  lw=2.5,  marker='o', mew = 2.5, markersize = 10, markerfacecolor='none', markeredgecolor=pcolor, dash_capstyle='round', label='128 way HYK Sort')


hss_dup = [3.87, 3.87, 3.87, 4.16, 4.96]
hss_nodup = [3.8296, 3.866, 3.8748, 4.06, 4.772]
pcolor = '#0e326d'
plt.plot(p, hss_nodup, '-', color=pcolor,  lw=2.5,  marker='x', mew = 2.5, markersize = 10, markerfacecolor='none', markeredgecolor=pcolor, dash_capstyle='round', label='HSS')



label_fontsize=15

leg = plt.legend(bbox_to_anchor=(0.10, 0.9), borderaxespad=0, loc=2, numpoints=3, handlelength=5, fontsize=label_fontsize)
leg.get_frame().set_linewidth(0.0)



axcolor='grey'
#ax.xaxis.set_tick_params(width=2, length=10)
#ax.yaxis.set_tick_params(width=2, length=10)
#ax.xaxis.set_tick_params(which='both', colors=axcolor)
#ax.yaxis.set_tick_params(which='both', colors=axcolor)


ax.spines['bottom'].set_color(axcolor)
ax.spines['top'].set_color(axcolor) 
ax.spines['right'].set_color(axcolor)
ax.spines['left'].set_color(axcolor)


def string(x):
    if x >= 1024:
    		return str(x/1024) + 'K'
    else:
        return str(x)

hfont = {'fontname':'Lato'}
plt.xlabel("#PEs", fontsize=label_fontsize)
plt.ylabel("Execution Time(sec)", fontsize=label_fontsize)


ticklabelcolor = 'black' #'grey'
logps = np.arange(10,17,1)
xticks = np.array([2**x for x in logps])
ax.xaxis.set_ticks(xticks)
xticks = np.array([string(x) for x in xticks])
ax.set_xticklabels(xticks, color=ticklabelcolor)

'''
logps = np.arange(0,38,4)
ax.yaxis.set_ticks(np.array([2**x for x in logps]))
yticks = np.array([2**x for x in logps])
yticks = np.array([string(x) for x in yticks])
ax.set_yticklabels(yticks, color=ticklabelcolor)
'''


#plt.xlim(xmin=500)
plt.ylim(ymin=3, ymax=6)

plt.grid(linestyle=':', linewidth=1, color='grey')
plt.tick_params(labelsize=label_fontsize)
plt.savefig('hyk_vs_hss.pdf')
