import math
import numpy as np
import matplotlib.pyplot as plt
import matplotlib
from matplotlib.ticker import AutoMinorLocator

matplotlib.rcParams['ytick.minor.size'] = 5
matplotlib.rcParams['ytick.minor.width'] = 1

matplotlib.rcParams['xtick.minor.size'] = 5
matplotlib.rcParams['xtick.minor.width'] = 1.5


fig, ax = plt.subplots()
ax.set_xscale("log", basex=2)


p = [480, 960, 1920, 3840, 7680]
told_nonsmp = [3.62, 4.66, (6.84 + 7.31)/2, 9.27, 13.12]
pcolor = '#0e326d'
plt.plot(p, told_nonsmp, '-', color=pcolor,  lw=2.5,  marker='|', mew = 2.5, markersize = 10, markerfacecolor='none', markeredgecolor=pcolor, dash_capstyle='round', label='Histogram sort')


p = [480, 960, 1920, 3840, 7680]
tnew = [3.21, 3.52, 3.54, 3.53, 4.02]
pcolor = '#028413'
plt.plot(p, tnew, '-', color=pcolor,  lw=2.5,  marker='o', mew = 2.5, markersize = 10, markerfacecolor='none', markeredgecolor=pcolor, dash_capstyle='round', label='HSS')


leg = plt.legend(bbox_to_anchor=(0.10, 0.9), borderaxespad=0, loc=2, numpoints=3, handlelength=5)
leg.get_frame().set_linewidth(0.0)



axcolor='grey'
ax.xaxis.set_tick_params(width=2, length=10)
ax.yaxis.set_tick_params(width=2, length=15)
ax.xaxis.set_tick_params(which='both', colors=axcolor)
ax.yaxis.set_tick_params(which='both', colors=axcolor)


ax.spines['bottom'].set_color(axcolor)
ax.spines['top'].set_color(axcolor) 
ax.spines['right'].set_color(axcolor)
ax.spines['left'].set_color(axcolor)

def string(x):
    if x >= 1024:
    		return str(x/1024) + 'K'
    else:
        return str(x)

hfont = {'fontname':'Lato'}
plt.xlabel("#cores", **hfont)
plt.ylabel("Execution Time(sec)")


ticklabelcolor = 'grey'

logps = np.arange(8,15,1)
ax.xaxis.set_ticks(np.array([2**x for x in logps]))
xticks = np.array([2**x for x in logps])
xticks = np.array([string(x) for x in xticks])
ax.set_xticklabels(xticks, color=ticklabelcolor)


yticks = np.arange(0,24,4)
ax.yaxis.set_ticks(yticks)
ax.yaxis.set_minor_locator(AutoMinorLocator(8))
ax.set_yticklabels(yticks, color=ticklabelcolor)



#plt.xlim(xmin=500)
#plt.ylim(ymin=0, ymax=18)

plt.grid(linestyle=':', linewidth=1, color='grey')

plt.show()

plt.savefig('/Users/vipulharsh/Desktop/psortingV/doc/2017ipdps-parsort/PAPER/fig2.eps')
